@@ -60,7 +60,7 @@ class Pipeline:
         self.running_container_managers: List[ContainerManager] = []
         self.finished_container_managers: List[ContainerManager] = []
         self.global_env_vars = {}
-        self.global_labels = {"copili.dzd-ev.de":"true"}
+        self.global_labels = {"copili.dzd-ev.de/container":"true"}
         atexit.register(self._atexit)
         signal.signal(signal.SIGTERM, self._atexit)
         signal.signal(signal.SIGINT, self._atexit)
